@@ -1,4 +1,5 @@
 from tapioca.rest_api import TornadoRESTful, ResourceHandler, \
         ResourceDoesNotExist
 from tapioca.serializers import Encoder, JsonEncoder, JsonpEncoder, HtmlEncoder
-from tapioca.request import RequestSchema, validate, optional
+from tapioca.request import RequestSchema, validate, optional, ParamError, \
+        ParamRequiredError, InvalidParamError
